#ifndef NT2_INCLUDE_FUNCTIONS_GENEIG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GENEIG_HPP_INCLUDED

#include <nt2/linalg/include/functions/geneig.hpp>

#endif
